@@ -6,8 +6,8 @@ import logging
 from trexlib.utils.log_util import get_tracelog
 from trexlib.utils.string_util import random_string
 from trexlib import conf as lib_conf
-
-logger = logging.getLogger('import')
+from datetime import datetime
+logger = logging.getLogger('task')
 
 
 # Resource to trigger task
@@ -46,7 +46,7 @@ class TriggerTaskBaseResource(Resource):
         except:
             logger.debug(get_tracelog())
         
-        return self.output_html("Triggered task_url=%s"% (task_url))
+        return self.output_html("Triggered task_url[%s]=%s"% (datetime.now(), task_url))
     
     def get_base_url(self):
         return lib_conf.SYSTEM_BASE_URL
