@@ -71,5 +71,9 @@ def last_day_of_month(date):
         return date.replace(day=31)
     return date.replace(month=date.month+1, day=1) - timedelta(days=1)
 
+def to_day_of_year(datetime_input):
+    return datetime_input.timetuple().tm_yday
+    
+
 
 
